@@ -1,9 +1,9 @@
 package Math::Currency;
 
 use strict;
-use integer;
-use Carp;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
+use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $PACKAGE $CLASSDATA);
+require Exporter;
+require Math::FixedPrecision;
 use overload 	'+'		=>	\&add,
 				'-'		=>	\&subtract,
 				'*'		=>	\&multiply,
@@ -14,11 +14,9 @@ use overload 	'+'		=>	\&add,
 				'abs'	=>	\&absolute,
 				'bool'	=>	\&boolean,
 				;
+use POSIX qw(locale_h);
 
-require Exporter;
-require Math::BigInt;
-
-@ISA = qw(Exporter Math::BigInt);
+@ISA = qw(Exporter Math::FixedPrecision);
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
@@ -29,17 +27,37 @@ require Math::BigInt;
 	Money
 );
 
-$VERSION = '0.03';
+$VERSION = '0.06';
 
-my $package = 'Math::Currency';
+$PACKAGE = 'Math::Currency';
 
-my $ClassData = {
-		SIGN		=>	'-',
-		PREFIX		=>	'$',
-		SEPARATOR	=>	',',
-		DECIMAL		=>	'.',
-		POSTFIX		=>	'',
+$CLASSDATA = {
+		SEPARATOR	=>	${localeconv()}{'mon_thousands_sep'} || ',',
+		DECIMAL		=>	${localeconv()}{'mon_decimal_point'} || '.',
 };
+if ( ${localeconv()}{'p_cs_precedes'} eq '0' )
+{
+	$CLASSDATA->{PREFIX}	= '';
+	$CLASSDATA->{POSTFIX}	= ${localeconv()}{'currency_symbol'} || '$';
+}
+else 
+{
+	$CLASSDATA->{PREFIX}	= ${localeconv()}{'currency_symbol'} || '$';
+	$CLASSDATA->{POSTFIX}	= '';
+}
+#	currency_symbol      = $
+#   frac_digits          = 2
+#	mon_decimal_point    = .
+#	mon_grouping         = 3 (get with unpack "C*" $locale_values->{'mon_decimal_point})
+#	mon_thousands_sep    = ,
+#	n_cs_precedes        = 1
+#	n_sep_by_space       = 0
+#	n_sign_posn          = 0
+#	negative_sign        = -
+#	p_cs_precedes        = 1
+#	p_sep_by_space       = 0
+#	p_sign_posn          = 3
+
 
 # Preloaded methods go here.
 ############################################################################
@@ -55,35 +73,7 @@ sub new		#05/10/99 3:13:PM
 
 	my $value = shift;
 	my $format = shift;
-	my $decimal = 0;
-	$value =~ tr/0-9.-//cd;		# Clean out non-numeric characters
-
-	# Normalize the number to 1234567.89
-	if ( ( $decimal = length($value) - index($value,'.') - 1 ) != length($value) )	# Already has a decimal
-	{
-		$value =~ tr/0-9-//cd;	# Strip the decimal
-		if ( $decimal <= 2 )	# Not enough decimal places
-		{
-			$value .= '0' x ( 2 - $decimal );
-		}
-		else					# Too many decimal places 
-		{
-			$decimal = length($value) - $decimal + 2;
-			my $remainder = substr( $value, $decimal, 1 );
-			$value = substr( $value, 0, $decimal );
-			if ( $remainder >= 5 )
-			{
-				$value += 1;
-			}
-		}
-	}
-	else 
-	{
-		$value .= '00';			# Has no decimal to start with
-	}
-
-	%$self = %$proto if ref $proto;
-	$self->{VAL} = Math::BigInt->new($value);
+	$self->{VAL} = Math::FixedPrecision->new($value,2);
 	$self->format($format) if $format;
 	return $self;
 }	##new
@@ -93,104 +83,106 @@ sub Money		#05/10/99 4:16:PM
 ############################################################################
 
 {
-	return $package->new(@_);
+	return $PACKAGE->new(@_);
 }	##Money
 
-############################################################################
-sub _new		#05/10/99 5:06:PM
-				# only use for values already offset by 100
-############################################################################
+##########################################################################
+#sub _new		#05/10/99 5:06:PM
+#				 only use for values already offset by 100
+###########################################################################
 
-{
-	my $proto  = shift;
-	my $class  = ref($proto) || $proto;
-	my $parent = ref($proto) && $proto;
+#{
+#	my $proto  = shift;
+#	my $class  = ref($proto) || $proto;
+#	my $parent = ref($proto) && $proto;
 
-	my $self = bless {}, $class;
+#	my $self = bless {}, $class;
 
-	my ( $value ) = shift;
-	%$self = %$proto if ref $proto;
-	$self->{VAL} = Math::BigInt->new($value);
-	return $self;
-}	##new_int
+#	my $value = shift;
+#	my $format = shift;
+#	%$self = %$proto if ref $proto;
+#	$self->{VAL} = Math::FixedPrecision->_new($value,2);
+#	$self->format($format) if $format;
+#	return $self;
+#}	##new_int
 
-############################################################################
+##########################################################################
 sub add		#05/10/99 5:00:PM
-############################################################################
+##########################################################################
 
 {
 	my($oper1,$oper2,$inverted) = @_;
 
 	unless ( ref $oper2 )
 	{
-		$oper2 = $package->new($oper2);
+		$oper2 = $PACKAGE->new($oper2);
 	}
 
-	return ( $package->_new($oper1->{VAL} + $oper2->{VAL}) ) unless $inverted;
-	return ( $package->_new($oper2->{VAL} + $oper1->{VAL}) )
+	return ( $PACKAGE->new( $oper1->{VAL} + $oper2->{VAL},$oper1->format ) ) unless $inverted;
+	return ( $PACKAGE->new( $oper2->{VAL} + $oper1->{VAL},$oper2->format ) )
 }	##add
 
 
-############################################################################
+##########################################################################
 sub subtract		#05/10/99 5:05:PM
-############################################################################
+##########################################################################
 
 {
 	my($oper1,$oper2,$inverted) = @_;
 
 	unless ( ref $oper2 )
 	{
-		$oper2 = $package->new($oper2);
+		$oper2 = $PACKAGE->new($oper2);
 	}
 
-	return ( $package->_new($oper1->{VAL} - $oper2->{VAL}) ) unless $inverted;
-	return ( $package->_new($oper2->{VAL} - $oper1->{VAL}) )
+	return ( $PACKAGE->new( $oper1->{VAL} - $oper2->{VAL},$oper1->format ) ) unless $inverted;
+	return ( $PACKAGE->new( $oper2->{VAL} - $oper1->{VAL},$oper2->format ) )
 }	##subtract
 
 
-############################################################################
+##########################################################################
 sub multiply		#05/10/99 5:12:PM
-############################################################################
+##########################################################################
 
 {
 	my($oper1,$oper2,$inverted) = @_;
 
 	unless ( ref $oper2 )
 	{
-		$oper2 = $package->new( $oper2 );
+		$oper2 = $PACKAGE->new( $oper2 );
 	}
 
-	return $package->_new( ($oper1->{VAL} * $oper2->{VAL} + 50) / 100 );
+	return $PACKAGE->new( $oper1->{VAL} * $oper2->{VAL},$oper1->format );
 	
 }	##multiply
 
-############################################################################
+##########################################################################
 sub divide		#05/10/99 5:12:PM
-############################################################################
+##########################################################################
 
 {
 	my($oper1,$oper2,$inverted) = @_;
 
 	unless ( ref $oper2 )
 	{
-		$oper2 = $package->new($oper2);
+		$oper2 = $PACKAGE->new($oper2);
 	}
 
-	return ( $package->_new( ($oper1->{VAL} * 100) / $oper2->{VAL}) ) unless $inverted;
-	return ( $package->_new( ($oper2->{VAL} * 100) / $oper1->{VAL}) )
+	return ( $PACKAGE->new( $oper1->{VAL} / $oper2->{VAL},$oper1->format ) ) unless $inverted;
+	return ( $PACKAGE->new( $oper2->{VAL} / $oper1->{VAL},$oper2->format ) )
 	
 }	##divide
 
-############################################################################
+##########################################################################
 sub spaceship		#05/10/99 3:48:PM
-############################################################################
+##########################################################################
 
 {
 	my($dollar1,$dollar2,$inverted) = @_;
 
 	unless ( ref $dollar2 )
 	{
-		$dollar2 = $package->new($dollar2);
+		$dollar2 = $PACKAGE->new($dollar2);
 	}
 
 	my $sgn = $inverted ? -1 : 1;
@@ -212,8 +204,8 @@ sub stringify		#05/10/99 3:52:PM
 	{
 		$value .= "0" x ( 3 - length($value) ) ;
 	}
-	substr($value,2,0) = ${$self->format}{DECIMAL};
-	$value=~ s/(\d{3})(?=\d)(?!\d*\.)/$1${$self->format}{SEPARATOR}/g;
+	$value =~ s/\./${$self->format}{DECIMAL}/;
+	$value =~ s/(\d{3})(?=\d)(?!\d*\.)/$1${$self->format}{SEPARATOR}/g;
 	$value = reverse $value;
 	if ( $neg )
 	{
@@ -244,18 +236,18 @@ sub format		#05/17/99 1:58:PM
 
 	unless ( ref $self )
 	{
-		$ClassData = @_[0] if @_;
-		return $ClassData;
+		$CLASSDATA = $_[0] if @_;
+		return $CLASSDATA;
 	}
 
-	$self->{Format} = @_[0] if @_;
+	$self->{Format} = $_[0] if @_;
 	if ( defined $self->{Format} )
 	{
 		return $self->{Format};
 	}
 	else 
 	{
-		return $ClassData;
+		return $CLASSDATA;
 	}
 }	##format
 
@@ -265,7 +257,7 @@ sub absolute		#06/15/99 4:47:PM
 
 {
 	my $self = shift;
-	return $package->_new( abs($self->{VAL}) );
+	return $PACKAGE->new( abs($self->{VAL}) );
 }	##absolute
 
 ############################################################################
@@ -292,7 +284,7 @@ __END__
 
 =head1 NAME
 
-Math::Currency - Perl extension for performing exact currency math
+Math::Currency - Exact Currency Math with Formatting and Rounding
 
 =head1 SYNOPSIS
 
@@ -316,9 +308,8 @@ allowed and division/multiplication should never create more accuracy than the
 original values.  All currency values should round to the closest cent or
 whatever the local equivalent should happen to be.
 
-This module employs Math::BigInt to perform its actual calculations (although
-I plan to change that to Bit::Vector soon), and has a flexible formatting
-scheme that should cover most formats in use worldwide.  A currency value can
+The default formatting methods 
+A currency value can
 have an individual format or the global currency format can be changed to
 reflect local usage.  I used the suggestions in Tom Christiansen's L<PerlTootC|http://www.perl.com/language/misc/perltootc.html#Translucent_Attributes>
 to implement translucent attributes.
@@ -334,6 +325,7 @@ John Peacock <JPeacock@UnivPress.com>
 =head1 SEE ALSO
 
 perl(1).
+perllocale
 
 
 =cut
